@@ -350,20 +350,17 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
 #        self.displayInputs(REQUEST)
         parent = aq_parent(self)
         labels = [parent[id].Title() for id in self.getOrder_description()]
-#        values = [safe_unicode(item.get('value')) for item in self.displayInputs(REQUEST) if item.get('label') in labels]
         items = {}
         for item in self.displayInputs(REQUEST):
             items.update({item.get('label'):item.get('value')})
-#        items = [{item.get('label'):item.get('value')} for item in self.displayInputs(REQUEST)]
-        values = [safe_unicode(items.get(label)) for label in labels]
-#        form = self.REQUEST.form
-#        values = [safe_unicode(form.get(key, '')) for key in self.getOrder_description()]
-        res = u','.join(values)
-#        res = safe_unicode(res)
-#        return res[:65000]
-        portal = getToolByName(self, 'portal_url').getPortalObject()
-        charset = portal.getProperty('email_charset', 'utf-8')
-        return res[:65000].encode(charset)
+        if len(items) == 0:
+            return ''
+        else:
+            values = [safe_unicode(items.get(label)) for label in labels if items.get(label) is not None and items.get(label) != '']
+            res = u','.join(values)
+            portal = getToolByName(self, 'portal_url').getPortalObject()
+            charset = portal.getProperty('email_charset', 'utf-8')
+            return res[:65000].encode(charset)
 
 
     def send_form(self, fields, request, **kwargs):
